/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "idlc/document.h"
#include "idlc/block.h"

namespace tidl {

Document::Document() {}

void Document::AddBlock(Block* block) {
  blocks_.emplace_back(block);
}

const std::list<std::unique_ptr<Block>>& Document::GetBlocks() const {
  return blocks_;
}

bool Document::ExistBlock(Block* block) const {
  for (auto& b : blocks_) {
    if (b->GetType() == block->GetType() &&
        b->GetID() == block->GetID())
      return true;
  }

  return false;
}

}  // namespace tidl
