/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <gtest/gtest.h>

#include <iostream>

#include "idlc/interface.h"

class InterfaceTest : public testing::Test {
 public:
  tidl::Declarations* decls;

  virtual void SetUp() {
    tidl::Parameters* params = new tidl::Parameters();
    EXPECT_NE(params, nullptr);
    params->Add(new tidl::Parameter("test1",
          new tidl::ParameterType(new tidl::BaseType("int", "")), __LINE__));
    params->Add(new tidl::Parameter("test2",
          new tidl::ParameterType(new tidl::BaseType("int", "")), __LINE__));
    tidl::Declaration* decl = new tidl::Declaration("test",
        new tidl::BaseType("int", ""), params, "", __LINE__);
    EXPECT_NE(decl, nullptr);
    decls = new tidl::Declarations();
    EXPECT_NE(decls, nullptr);
    decls->Add(decl);
  }
  virtual void TearDown() {}
};

TEST_F(InterfaceTest, Interface_Constructor) {
  tidl::Interface* interface = new tidl::Interface("TestInterface", decls,
      "", new tidl::Attributes(), __LINE__);
  EXPECT_NE(interface, nullptr);
  delete interface;
}

TEST_F(InterfaceTest, Interface_GetDeclrations) {
  tidl::Interface* interface = new tidl::Interface("TestInterface", decls,
      "", new tidl::Attributes(), __LINE__);
  EXPECT_NE(interface, nullptr);

  bool flag = false;
  for (auto& d : interface->GetDeclarations().GetDecls()) {
    if (d->GetID() == "test")
      flag = true;
  }
  EXPECT_EQ(flag, true);
  delete interface;
}

TEST_F(InterfaceTest, Interface_GetID) {
  tidl::Interface* interface = new tidl::Interface("TestInterface", decls,
      "", new tidl::Attributes(), __LINE__);
  EXPECT_NE(interface, nullptr);
  EXPECT_EQ(interface->GetID(), "TestInterface");
  delete interface;
}

TEST_F(InterfaceTest, Interface_GetType) {
  tidl::Interface* interface = new tidl::Interface("TestInterface", decls,
      "", new tidl::Attributes(), __LINE__);
  EXPECT_NE(interface, nullptr);
  EXPECT_EQ(interface->GetType(), tidl::Interface::TYPE_INTERFACE);
  delete interface;
}

TEST_F(InterfaceTest, Interface_GetLine) {
  unsigned line = __LINE__;
  tidl::Interface* interface = new tidl::Interface("TestInterface", decls,
      "", new tidl::Attributes(), line);
  EXPECT_NE(interface, nullptr);
  EXPECT_EQ(interface->GetLine(), line);
  delete interface;
}

TEST_F(InterfaceTest, Interface_GetComments) {
  std::string comments = "Test Interface";
  tidl::Interface* interface = new tidl::Interface("TestInterface", decls,
      comments, new tidl::Attributes(), __LINE__);
  EXPECT_NE(interface, nullptr);
  EXPECT_EQ(interface->GetComments(), comments);
  delete interface;
}

